=======
Credits
=======

Development Lead
----------------

* Michael Warkentin <mwarkentin@gmail.com> - https://github.com/mwarkentin

Contributors
------------

* Keryn Knight - https://github.com/kezabelle
* blag - https://github.com/blag
